import { AnimationOptions } from '../contracts';
export declare enum AnimationMode {
    Animate = 0,
    Show = 1,
    Hide = 2
}
export declare class AnimationBuilder {
    private static _DEBUG;
    private static _disabled;
    private static _defaults;
    private static raf;
    private animationOptions;
    private defaultOptions;
    private classes;
    private activeClasses;
    private listeners;
    private timeouts;
    private styles;
    constructor();
    show(element: HTMLElement): Promise<HTMLElement>;
    hide(element: HTMLElement): Promise<HTMLElement>;
    stop(element: HTMLElement, reset?: boolean): Promise<HTMLElement>;
    animate(element: HTMLElement, mode?: AnimationMode): Promise<HTMLElement>;
    reset(element: HTMLElement, removePending?: boolean, rejectTimeouts?: boolean, rejectListeners?: boolean): void;
    dispose(): void;
    addAnimationClass(name: string): AnimationBuilder;
    removeAnimationClass(name: string): AnimationBuilder;
    static get DEBUG(): boolean;
    static set DEBUG(debug: boolean);
    static get disabled(): boolean;
    static set disabled(disabled: boolean);
    static get defaults(): AnimationOptions;
    animateDisabled(element: HTMLElement, mode: AnimationMode): Promise<HTMLElement>;
    private log;
    private nextFrame;
    private camelCase;
    private hideElement;
    private showElement;
    private pinElement;
    private getPosition;
    private registerAnimationListeners;
    private addTimeout;
    private addListener;
    private removeListeners;
    private removeTimeouts;
    private animationEndEvent;
    private animationStartEvent;
    private applyProperties;
    private saveStyle;
    private applyStyles;
    private removeStyles;
    private saveClasses;
    private applyClasses;
    private removeClasses;
    private applyStyle;
    get defaults(): AnimationOptions;
    set defaults(defaults: AnimationOptions);
    setDefaults(defaults: AnimationOptions): AnimationBuilder;
    get options(): AnimationOptions;
    set options(options: AnimationOptions);
    setOptions(options: AnimationOptions): AnimationBuilder;
    get disabled(): boolean;
    set disabled(disabled: boolean);
    get reject(): boolean;
    set reject(reject: boolean);
    get pin(): boolean;
    set pin(pin: boolean);
    setPin(pin: boolean): AnimationBuilder;
    get useVisibility(): boolean;
    set useVisibility(useVisibility: boolean);
    setUseVisibility(useVisibility: boolean): AnimationBuilder;
    get type(): string;
    set type(type: string);
    setType(type: string): AnimationBuilder;
    get fillMode(): string;
    set fillMode(fillMode: string);
    setFillMode(fillMode: string): AnimationBuilder;
    applyFillMode(element: HTMLElement, fillMode?: string): AnimationBuilder;
    get timingFunction(): string;
    set timingFunction(timingFunction: string);
    setTimingFunction(timingFunction: string): AnimationBuilder;
    applyTimingFunction(element: HTMLElement, timingFunction?: string): AnimationBuilder;
    get playState(): string;
    set playState(playState: string);
    setPlayState(playState: string): AnimationBuilder;
    applyPlayState(element: HTMLElement, playState?: string): AnimationBuilder;
    get direction(): string;
    set direction(direction: string);
    setDirection(direction: string): AnimationBuilder;
    applyDirection(element: HTMLElement, direction?: string): AnimationBuilder;
    get duration(): number;
    set duration(duration: number);
    setDuration(duration: number): AnimationBuilder;
    applyDuration(element: HTMLElement, duration?: number): AnimationBuilder;
    get delay(): number;
    set delay(delay: number);
    setDelay(delay: number): AnimationBuilder;
    applyDelayAsStyle(element: HTMLElement, delay?: number): AnimationBuilder;
    get iterationCount(): number | string;
    set iterationCount(iterationCount: number | string);
    setIterationCount(iterationCount: number | string): AnimationBuilder;
    applyIterationCount(element: HTMLElement, iterationCount?: number | string): AnimationBuilder;
}
